# National Water Model Tethys plugins

## Installation

Install from pip.

```bash
pip install nwm_plugins
```

## Development

Follow these steps:

1. Clone this repository to your local machine.
2. Navigate to the `nwmp_plugins` directory.
3. Run the following command

   ```bash
   pip install -e .
   ```
